##  Result
You receive the report as an XLSX spreadsheet.
![The downloaded spreadsheet showing columns for Author, Change Time, Column, Old Value, and New Value](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio072086f9207a440fb3e30dc38290a801_HiRes.png)
YesNo
Send
